@@ -32,26 +32,35 @@ class Client(TonClient, metaclass=SingletonMeta):
 
     async def run_local(
             self,
-            account: 'Account',
             abi: AbiContract,
             method: str,
+            account: 'Account' = None,
+            account_params: (str, str) = None,
             params: dict = None,
             parse: bool = False,
     ) -> dict | Any:
         """
+        Use account or address_params
         :return: dict in case of `parse` is False, otherwise parse response and return Any type
         """
+        assert account is not None or account_params is not None, 'Arg `account` or `account_params` must be provided'
+        if account is not None:
+            address = account.address
+            account_boc = account.data.boc
+        else:
+            address, account_boc = account_params
+
         abi = Abi.Contract(abi)
         call_set = CallSet(function_name=method, input=params)
         message_params = ParamsOfEncodeMessage(
             abi=abi,
-            address=account.address,
+            address=address,
             signer=Signer.NoSigner(),
             call_set=call_set,
         )
         message = await self.abi.encode_message(params=message_params)
 
-        run_params = ParamsOfRunTvm(message=message.message, account=account.data.boc, abi=abi)
+        run_params = ParamsOfRunTvm(message=message.message, account=account_boc, abi=abi)
         result = await self.tvm.run_tvm(params=run_params)
         decoded = result.decoded.output
 
